==> vue-carousel-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/carousel/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { iconChevronLeft, iconChevronRight } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["initialIndex", "height", "trigger", "autoplay", "interval", "indicatorPosition", "arrow", "type", "showTitle", "loop"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  },
  components: {
    IconChevronLeft: iconChevronLeft(),
    IconChevronRight: iconChevronRight()
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["tiny-carousel", {
      "tiny-carousel--card": _vm.type === "card"
    }],
    on: {
      "mouseenter": function mouseenter($event) {
        $event.stopPropagation();
        return _vm.handleMouseEnter.apply(null, arguments);
      },
      "mouseleave": function mouseleave($event) {
        $event.stopPropagation();
        return _vm.handleMouseLeave.apply(null, arguments);
      }
    }
  }, [_c("div", {
    staticClass: "tiny-carousel__container",
    style: {
      height: _vm.height
    }
  }, [_c("transition", {
    attrs: {
      "name": "tiny-transition-carousel-arrow-left"
    }
  }, [_vm.arrow !== "never" ? _c("button", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: (_vm.arrow === "always" || _vm.state.hover) && (_vm.loop || _vm.state.activeIndex > 0),
      expression: "(arrow === 'always' || state.hover) && (loop || state.activeIndex > 0)"
    }],
    staticClass: "tiny-carousel__arrow tiny-carousel__arrow-left",
    attrs: {
      "type": "button"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.handleButtonEnter("left");
      },
      "mouseleave": _vm.handleButtonLeave,
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.throttledArrowClick(_vm.state.activeIndex - 1);
      }
    }
  }, [_c("icon-chevron-left", {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e()]), _c("transition", {
    attrs: {
      "name": "tiny-transition-carousel-arrow-right"
    }
  }, [_vm.arrow !== "never" ? _c("button", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: (_vm.arrow === "always" || _vm.state.hover) && (_vm.loop || _vm.state.activeIndex < _vm.state.items.length - 1),
      expression: "(arrow === 'always' || state.hover) && (loop || state.activeIndex < state.items.length - 1)"
    }],
    staticClass: "tiny-carousel__arrow tiny-carousel__arrow-right",
    attrs: {
      "type": "button"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.handleButtonEnter("right");
      },
      "mouseleave": _vm.handleButtonLeave,
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.throttledArrowClick(_vm.state.activeIndex + 1);
      }
    }
  }, [_c("icon-chevron-right", {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e()]), _vm._t("default")], 2), _vm.indicatorPosition !== "none" ? _c("ul", {
    staticClass: "tiny-carousel__indicators",
    class: {
      "tiny-carousel__indicators-vertical": _vm.type === "vertical",
      "tiny-carousel__indicators-title": _vm.showTitle,
      "tiny-carousel__indicators-labels": _vm.state.hasLabel,
      "tiny-carousel__indicators-outside": _vm.indicatorPosition === "outside" || _vm.type === "card"
    }
  }, _vm._l(_vm.state.items, function(item, index) {
    return _c("li", {
      key: index,
      class: ["tiny-carousel__indicator", {
        "is-active": index === _vm.state.activeIndex
      }],
      on: {
        "mouseenter": function mouseenter($event) {
          return _vm.throttledIndicatorHover(index);
        },
        "click": function click($event) {
          $event.stopPropagation();
          return _vm.handleIndicatorClick(index);
        }
      }
    }, [_c("button", {
      staticClass: "tiny-carousel__button",
      attrs: {
        "type": "button"
      }
    }, [_vm.state.hasLabel ? _c("span", [_vm._v(_vm._s(item.label))]) : _vm._e()])]);
  }), 0) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-carousel-2.24.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/carousel/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconChevronLeft, iconChevronRight, iconChevronUp, iconChevronDown } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/carousel/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["change", "complete"],
  props: [].concat(props, ["initialIndex", "height", "trigger", "autoplay", "interval", "indicatorPosition", "arrow", "type", "showTitle", "loop", "disabled", "swipeable", "lite", "beforeSwipe"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  },
  components: {
    IconChevronLeft: iconChevronLeft(),
    IconChevronRight: iconChevronRight(),
    IconChevronUp: iconChevronUp(),
    IconChevronDown: iconChevronDown()
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-carousel",
    class: {
      "tiny-carousel--card": _vm.type === "card"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        $event.stopPropagation();
        return _vm.handleMouseEnter.apply(null, arguments);
      },
      "mouseleave": function mouseleave($event) {
        $event.stopPropagation();
        return _vm.handleMouseLeave.apply(null, arguments);
      }
    }
  }, [_c("div", {
    staticClass: "tiny-carousel__container",
    style: {
      height: _vm.height
    }
  }, [_c("transition", {
    attrs: {
      "name": _vm.type === "vertical" ? "tiny-transition-carousel-arrow-top" : "tiny-transition-carousel-arrow-left"
    }
  }, [_vm.state.hasButtons ? _c("button", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: (_vm.arrow === "always" || _vm.state.hover) && (_vm.loop || _vm.state.activeIndex > 0),
      expression: "(arrow === 'always' || state.hover) && (loop || state.activeIndex > 0)"
    }],
    class: ["tiny-carousel__arrow", _vm.type === "vertical" ? "tiny-carousel__arrow-top" : "tiny-carousel__arrow-left", _vm.disabled && _vm.state.activeIndex === 0 ? "tiny-carousel__arrow-disabled" : ""],
    attrs: {
      "type": "button",
      "disabled": _vm.loop && _vm.disabled && _vm.state.activeIndex === 0
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.handleButtonEnter("left");
      },
      "mouseleave": _vm.handleButtonLeave,
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.throttledArrowClick(_vm.state.activeIndex - 1);
      }
    }
  }, [_c(_vm.type === "vertical" ? "icon-chevron-up" : "icon-chevron-left", {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e()]), _c("transition", {
    attrs: {
      "name": _vm.type === "vertical" ? "tiny-transition-carousel-arrow-bottom" : "tiny-transition-carousel-arrow-right"
    }
  }, [_vm.state.hasButtons ? _c("button", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: (_vm.arrow === "always" || _vm.state.hover) && (_vm.loop || _vm.state.activeIndex < _vm.state.items.length - 1),
      expression: "(arrow === 'always' || state.hover) && (loop || state.activeIndex < state.items.length - 1)"
    }],
    class: ["tiny-carousel__arrow", _vm.type === "vertical" ? "tiny-carousel__arrow-bottom" : "tiny-carousel__arrow-right", _vm.disabled && _vm.state.activeIndex === _vm.state.items.length - 1 ? "tiny-carousel__arrow-disabled" : ""],
    attrs: {
      "type": "button",
      "disabled": _vm.loop && _vm.disabled && _vm.state.activeIndex === _vm.state.items.length - 1
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.handleButtonEnter("right");
      },
      "mouseleave": _vm.handleButtonLeave,
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.throttledArrowClick(_vm.state.activeIndex + 1);
      }
    }
  }, [_c(_vm.type === "vertical" ? "icon-chevron-down" : "icon-chevron-right", {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e()]), _vm._t("default")], 2), _vm.state.hasIndicators ? _c("ul", {
    staticClass: "tiny-carousel__indicators",
    class: {
      "tiny-carousel__indicators-labels": _vm.state.hasLabel,
      "tiny-carousel__indicators-title": _vm.showTitle,
      "tiny-carousel__indicators-vertical": _vm.type === "vertical",
      "tiny-carousel__indicators-outside": _vm.indicatorPosition === "outside" || _vm.type === "card"
    }
  }, _vm._l(_vm.state.items, function(item, index) {
    return _c("li", {
      key: index,
      staticClass: "tiny-carousel__indicator",
      class: {
        "is-active": index === _vm.state.activeIndex
      },
      on: {
        "mouseenter": function mouseenter($event) {
          return _vm.throttledIndicatorHover(index);
        },
        "click": function click($event) {
          $event.stopPropagation();
          return _vm.handleIndicatorClick(index);
        }
      }
    }, [_c("button", {
      staticClass: "tiny-carousel__button",
      attrs: {
        "type": "button"
      }
    }, [_vm.state.hasLabel ? _c("span", [_vm._v(_vm._s(item.label))]) : _vm._e()])]);
  }), 0) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
